# dsm-services
python library for useage services

## Install
- install stable version
```
pip install dsm-services
```

- install latest(dev mode)
```
pip install git+https://github.com/storemesh/dsm-services.git
```

# How to use
- NLP : Netural Language Processing
    - keyword extraction [doc](/docs/nlp.md)
    - NER : Named Entity Recognition [doc](/docs/nlp.md)
    - POS : Part Of Speech [doc](/docs/nlp.md)
- PDF2Text : Convert PDF file to Text [doc](/docs/pdf.md)
- Analyzer : LLM RAG WIZMAP [doc](/docs/analyzer.md)
- Monad : Handle error [doc](/docs/monad.md)
- LLM : Large Language Mode [doc](/docs/llm.md)